<?php
/*
Plugin Name: Tweet It
Description: A simple widget for enabling users to broadcast a message to their Twitter followers that they are reading your blog.
Version: 1.0
Author: 8BIT
Author URI: http://8bit.io
License:

    Copyright 2011 8BIT

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

class Tweet_It extends WP_Widget {

	/**
	 * The widget constructor. Specifies the classname and description, instantiates
	 * the widget, loads localization files, and includes necessary scripts and
	 * styles.
	 */
	function Tweet_It() {
		
		$widget_opts = array(
			'classname' => 'tweet-it-widget',
			'description' => 'A simple widget for enabling users to broadcast a message to their Twitter followers that they are reading your blog.',
		);
		$this->WP_Widget('tweet-it-widget', 'Tweet It Widget', $widget_opts);
		
		if(is_admin()) {
		
			$admin_style_url = WP_PLUGIN_URL . '/tweet-it/css/tweet-it.css';
			$admin_style_file = WP_PLUGIN_DIR . '/tweet-it/css/tweet-it.css';
			if(file_exists($admin_style_file)) {
				wp_register_style('tweet-it-styles', $admin_style_url);
				wp_enqueue_style('tweet-it-styles');
			}
			
			$admin_script_url = WP_PLUGIN_URL . '/tweet-it/javascript/tweet-it.js';
			$admin_script_file = WP_PLUGIN_DIR . '/tweet-it/javascript/tweet-it.js';
			if(file_exists($admin_script_file)) {
				wp_register_script('tweet-it-script', $admin_script_url);
				wp_enqueue_script('tweet-it-script');
			}
			
		} else {
		
			$admin_style_url = WP_PLUGIN_URL . '/tweet-it/css/tweet-it-display.css';
			$admin_style_file = WP_PLUGIN_DIR . '/tweet-it/css/tweet-it-display.css';
			if(file_exists($admin_style_file)) {
				wp_register_style('tweet-it-display-styles', $admin_style_url);
				wp_enqueue_style('tweet-it-display-styles');
			}
		
		}
		
	} // end constructor
	
	/**
	 * Outputs the content of the widget.
	 *
	 * @args			The array of form elements
	 * @instance
	 */
	function widget($args, $instance) { 
	
		extract($args, EXTR_SKIP);
		
		$use_custom_info = empty($instance['use_custom_info']) ? '' : apply_filters('use_custom_info', $instance['use_custom_info']);
		$custom_message = empty($instance['custom_message']) ? '' : apply_filters('custom_message', $instance['custom_message']);
	
	?>

	<div class="tweet-it-container">
		<a href="http://twitter.com/home?status=<?php if($use_custom_info): echo urlencode($custom_message); else: echo "I'm visiting "; echo bloginfo('title') . " "; bloginfo('url'); endif; ?>" title="Tweet It" target="_blank">
			Tweet It
		</a>
	</div>
	
<?php
	} // end widget
	
	/**
	 * Processes the widget's options to be saved.
	 *
	 * @new_instance	The previous instance of values before the update.
	 * @old_instance	The new instance of values to be generated via the update.
	 */
	function update($new_instance, $old_instance) {
		
		$instance = $old_instance;
		
		$instance['use_custom_info'] = strip_tags(stripslashes($new_instance['use_custom_info']));
		$instance['custom_message'] = strip_tags(stripslashes($new_instance['custom_message']));
		
		return $instance;
		
	} // end widget
	
	/**
	 * Generates the administration form for the widget.
	 *
	 * @instance	The array of keys and values for the widget.
	 */
	function form($instance) {
		
		$instance = wp_parse_args(
			(array)$instance,
			array(
				'use_custom_info' => '',
				'custom_message' => ''
			)
		);
		
		$use_custom_info = strip_tags(stripslashes($instance['use_custom_info']));
		$custom_message = strip_tags(stripslashes($instance['custom_message']));
		
?>
	<p class="tweet-it-note">
		Tweet It allows the user to publish your blog's title and URL via their Twitter account.
	</p>
	<p class="tweet-it-note">
		Would you rather define a custom message for the widget to publish?
	</p>
	<div class="tweet-it-options">
		<input type="checkbox" name="<?php echo $this->get_field_name('use_custom_info'); ?>" id="<?php echo $this->get_field_id('use_custom_info'); ?>" <?php if($instance['use_custom_info'] == 'on') { echo 'checked="checked"'; } ?> />
		<label for="<?php echo $this->get_field_id('use_custom_info'); ?>">
			Use Custom Message?
		</label>
		<input type="text" name="<?php echo $this->get_field_name('custom_message'); ?>" id="<?php echo $this->get_field_id('custom_message'); ?>" value="<?php echo $instance['custom_message']; ?>" />
	</div>

<?php
	} // end form
	
} // end class
add_action('widgets_init', create_function('', 'register_widget("Tweet_It");'));
?>